--联盟系统 创建联盟Window
checkRequire("Lua_AllianceLimitItem");
Lua_AllianceCreateWindow = class("Lua_AllianceCreateWindow", Lua_Window);

function Lua_AllianceCreateWindow:ctor()
	self:superCall("ctor");

	self.w = 600;
	self.h = 800;
	self.showClose = true;
	self.isClickClose = true;
	self.showBlackMask = true;

	self.windowName = "Lua_AllianceCreateWindow";
	self.skinName = "AllianceCreateWindow_skin";
end

function Lua_AllianceCreateWindow:buildShowItem()
	self:superCall("buildShowItem");

	--配置表中所需VIP等级为空，则不需要VIP等级限制
	self.VIPLevel = DataCenter.allianceUtil:getConstConfig("create_league_vip_level", 1);
	self.needVIP = self.VIPLevel ~= nil;
	self.createLimitTxt.text = self.needVIP and LanUtil.formateStr(201235, self.VIPLevel) or "";

	self.limitItemArr = Array();
	local applyLimitInfo = DataCenter.allianceUtil:getConstConfig("apply_limit", 5);
	local item;
	for i = 1, #applyLimitInfo do
		item = Lua_AllianceLimitItem.new(self.content, 1, applyLimitInfo[i]);
		item:setLocation(2, 150 - (i - 1) * 60, 0);
		self.limitItemArr:add(item);
	end

	applyLimitInfo = DataCenter.allianceUtil:getConstConfig("verify_option", 5);
	item = Lua_AllianceLimitItem.new(self.content, 2, applyLimitInfo);
	item:setLocation(2, 30, 0);
	self.limitItemArr:add(item);

	self.leagueNameInput:setDefaultLangValue(201108)
	self.leagueNameInput.characterLimit = DataCenter.allianceUtil:getConstConfig("max_name_len", 1);
	self.leagueNameInput.colorStr = Lua_ColorDefine.transColorStr("9C8472");

	self.noticeInput.defaultText = DataCenter.allianceUtil:getConstConfig("default_league_declaration", 4);
	self.noticeInput.characterLimit = DataCenter.allianceUtil:getConstConfig("max_notice_len", 1);
	self.noticeInput.colorStr = Lua_ColorDefine.transColorStr("846651");
	self.noticeInput:onChange(self, self.onChangeShow);

	local createCost = DataCenter.allianceUtil:getConstConfig("create_use", 5);
	local vo = Lua_ToolVo.createToolVo(createCost[1]);
	self.costIcon:setAltas(vo.iconAtlas, vo.iconSprite);
	self.moneyTxt.text = createCost[2];
	self.createBtn:addClickFuntion(self, self.onCreateBtnClick);

	self:onChangeShow();
end

function Lua_AllianceCreateWindow:dispose()
	if self.limitItemArr ~= nil then
		self.limitItemArr:dispose();
		self.limitItemArr = nil;
	end
	self:superCall("dispose");
end

function Lua_AllianceCreateWindow:onChangeShow()
	local infactLen = utf8len(self.noticeInput.text);
	local totalLen = self.noticeInput.characterLimit / 2;
	if infactLen > totalLen then
		infactLen = totalLen;
		self.noticeInput.text = utf8sub(self.noticeInput.text, 1, totalLen);
	end
	self.numTxt.text = infactLen .. "/" .. totalLen;
end

function Lua_AllianceCreateWindow:onCreateBtnClick(go)
	if self.needVIP and DataCenter.roleData.vip < self.VIPLevel then
		OperateAlert.showLangValue(201111);
		return;
	end

	local createCost = DataCenter.allianceUtil:getConstConfig("create_use", 5);
	local costId = DataCenter.packData:checkConsumeEnough(createCost);
	if costId ~= nil then
		DataCenter.packUtil:openPathWindow(costId);
		return;
	end	
	
	local leagueNameStr = self.leagueNameInput.text;
	if leagueNameStr == "" or leagueNameStr == LanUtil.getValue(201108) then
		OperateAlert.showLangValue(201108);
		return;
	end

	local leagueNameNum = stringWidth(leagueNameStr);
	local leagueNameLimit = DataCenter.allianceUtil:getConstConfig("max_name_len", 5);
	if leagueNameNum < leagueNameLimit[1] or leagueNameNum > leagueNameLimit[2] then
		OperateAlert.showLangValue(201109);
		return;
	end

	if Lua_CommonUtil.checkIsInvalid(leagueNameStr, false, LanUtil.getValue(201250)) then
		return;
	end

	-- 检测多数字或多字母
	local num_word = Lua_ChatUtil.checkSendMsg(leagueNameStr);
	if num_word == 1 or num_word == 2 then
		OperateAlert.showLangValue(171020);
		return;
	end

	local noticeStr = self.noticeInput.text;
	if noticeStr == "" or noticeStr == DataCenter.allianceUtil:getConstConfig("default_league_declaration", 4) then
		noticeStr = nil;
	end

	if Lua_CommonUtil.checkIsInvalid(noticeStr, true, LanUtil.getValue(201251)) then
		return;
	end

	local sec = DataCenter.roleData.serverTime - DataCenter.allianceData.lastQuitTick;
	local limit = DataCenter.allianceUtil:getConstConfig("quit_league_time_limit", 6);
	sec = limit - sec;
	if sec > 0 then
		local str;
		local hour = Mathf.Modf(sec / 3600);
		if hour < 1 then
			if sec < 60 then
				str = "1"..LanUtil.getValue(45);
			else
				str = Mathf.Modf(sec / 60)..LanUtil.getValue(45);
			end
		else
			str = Lua_TimeTransform.transSeconds23(sec, true, false);
		end
		OperateAlert.show(LanUtil.formateStr(201210, str));
		return;
	end

	Lua_ProxyManager.getProxy("Lua_AllianceProxy"):sCreateAlliance(leagueNameStr, self.limitItemArr[2].getRealValue, 
		self.limitItemArr[1].getRealValue, self.limitItemArr[3].getRealValue, noticeStr);
	self:hide();
end