--联盟系统 联盟列表Panel
Lua_AllianceListPanel = class("Lua_AllianceListPanel", Lua_DisplayObject);

function Lua_AllianceListPanel:ctor(p)
	self:superCall("ctor", p, "AllianceListPanel_skin");
end

function Lua_AllianceListPanel:buildPanel()
	self:superCall("buildPanel");
	self:addLuaEvent("UPDATE_LEAGUE_LIST", self, self.updateData);
	self:addLuaEvent("UPDATE_LEAGUE_SEARCH_LIST", self, self.updateSearchData);
end

function Lua_AllianceListPanel:buildShowItem()
	self:superCall("buildShowItem");

	Lua_ProxyManager.getProxy("Lua_AllianceProxy"):sGetAllianceList(0);

	self.isSearch = false;
	self.onlyCheck = false;

	self.listBg:SetDimensions(720, 756 + self.adaptHeight);
	self.contentBg:SetDimensions(720, 938 + self.adaptHeight);

	self.dragList = Lua_DragList.new(self.content, 690, 740 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.dragList:setListCell(Lua_AllianceListItem, 690, 130, 1);
    self.dragList:setLocation(0, -56, 0);
    self.dragList.callBackOwner = self;
    self.dragList.turnPageCallBack = self.addPage;
    self.dragList.tweenId = 2010;

    self.searchInput:setDefaultLangValue(201108)
	self.searchInput.characterLimit = DataCenter.allianceUtil:getConstConfig("max_name_len", 1);

    self.checkBox:addBoxChange(self, self.onCheckBoxChange);
    self.searchBtn:addClickFuntion(self, self.onSearchBtnClick);
    self.showListBtn:addClickFuntion(self, self.onShowListBtnClick);
    self.noneTxt:addClickFuntion(self, self.onShowListBtnClick);
    self.oneKeyApplyBtn:addClickFuntion(self, self.onOneKeyApplyBtnClick);
    self.createBtn:addClickFuntion(self, self.onCreateBtnClick);
end

function Lua_AllianceListPanel:dispose()
	if self.dragList ~= nil then
		self.dragList:dispose();
		self.dragList = nil;
	end

	DataCenter.allianceData:disposeAllianceList();
	self:superCall("dispose");
end

function Lua_AllianceListPanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);

	self.listBg:SetDimensions(720, 756 + adaptHeight);
	self.contentBg:SetDimensions(720, 938 + adaptHeight);
	self.dragList:setContentRect(710, 740 + adaptHeight);
end

function Lua_AllianceListPanel:updateData()
	self.isSearch = false;

	local data;
	if self.onlyCheck then
		data = DataCenter.allianceData.leagueLimitArr;
	else
		data = DataCenter.allianceData.leagueListArr;
	end

	self.noneObj:SetActive(false);
	self.dragList:setEnable(true);
	self.dragList:setArrayData(data);
	self.dragList.isPageEnd = DataCenter.allianceData.isPageEnd;
end

function Lua_AllianceListPanel:updateSearchData()
	self.isSearch = true;

	local data;
	if self.onlyCheck then
		data = DataCenter.allianceData.leagueSearchLimitArr;
	else
		data = DataCenter.allianceData.leagueSearchArr;
	end

	if data:getSize() <= 0 then
		self.noneObj:SetActive(true);
		self.dragList:setEnable(false);
	else
		self.noneObj:SetActive(false);
		self.dragList:setEnable(true);
		self.dragList:setArrayData(data);
	end
	self.dragList.isPageEnd = true;
end

function Lua_AllianceListPanel:onCheckBoxChange(val)
	self.onlyCheck = val;

	if self.isSearch then
		self:updateSearchData();
	else
		self:updateData();
	end
end

function Lua_AllianceListPanel:onSearchBtnClick(go)
	local searchStr = self.searchInput.text;
	if searchStr == nil or searchStr == "" or searchStr == LanUtil.getValue(201108) then
		OperateAlert.showLangValue(201108);
		return;
	end
	Lua_ProxyManager.getProxy("Lua_AllianceProxy"):sAllianceSearch(searchStr);
end

function Lua_AllianceListPanel:onShowListBtnClick(go)
	DataCenter.allianceData:disposeAllianceList();
	Lua_ProxyManager.getProxy("Lua_AllianceProxy"):sGetAllianceList(0);
end

function Lua_AllianceListPanel:onOneKeyApplyBtnClick(go)
	local sec = DataCenter.roleData.serverTime - DataCenter.allianceData.lastQuitTick;
	local limit = DataCenter.allianceUtil:getConstConfig("quit_league_time_limit", 6);
	sec = limit - sec;
	if sec > 0 then
		local str;
		local hour = Mathf.Modf(sec / 3600);
		if hour < 1 then
			if sec < 60 then
				str = "1"..LanUtil.getValue(45);
			else
				str = Mathf.Modf(sec / 60)..LanUtil.getValue(45);
			end
		else
			str = Lua_TimeTransform.transSeconds23(sec, true, false);
		end
		OperateAlert.show(LanUtil.formateStr(201210, str));
		return;
	end
	Lua_ProxyManager.getProxy("Lua_AllianceProxy"):sJoinAlliance(0);
end

function Lua_AllianceListPanel:onCreateBtnClick(go)
	Lua_WindowUtil.openWin("Lua_AllianceCreateWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_AllianceListPanel:addPage()
	if DataCenter.allianceData.isPageEnd then return end

	Lua_ProxyManager.getProxy("Lua_AllianceProxy"):sGetAllianceList(1);
end




















Lua_AllianceListItem = class("Lua_AllianceListItem", Lua_ListCell);

function Lua_AllianceListItem:ctor(p)
	self:superCall("ctor", p, "AllianceListItem_skin");
end

function Lua_AllianceListItem:buildShowItem()
	self:superCall("buildShowItem");

	self.headIcon = Lua_AvatarItem.new(self.content);
	self.headIcon:setLocation(-280, 0, 0);

	self.applyBtn:addClickFuntion(self, self.OnApplyBtnClick);
end

function Lua_AllianceListItem:dispose()
	if self.headIcon ~= nil then
		self.headIcon:dispose();
		self.headIcon = nil;
	end
	self:superCall("dispose");
end

function Lua_AllianceListItem:setData(data)
	self.data = data;

	local sprite = DataCenter.allianceUtil:getAllianceHeadByIndex(data.head, 1);
	self.headIcon:setLeagueAvatar(sprite);
	self.headIcon:setLeagueLevel(LanUtil.formateStr(201102, data.level));

	self.leagueNameTxt.text = data.showLeagueName;
	self.leaderNameTxt.text = LanUtil.formateStr(201101, data.leaderName);
	self.memberNumTxt.text = data.memberAmount .. "/" .. data.maxMember;

	local limitStr = "";
	if data.forceCond > 0 then
		limitStr = LanUtil.formateStr(201103, numberTrans(data.forceCond));
	end
	if data.levelCond > 0 then
		if limitStr ~= "" then
			limitStr = limitStr .. "\n";
		end
		limitStr = limitStr .. LanUtil.formateStr(201104, numberTrans(data.levelCond));
	end
	self.limitTxt.text = limitStr;

	if data.isMaxMember then
		self.applyBtn:setLangValue(201107);
		self.applyBtn:setBtnEnable(false);
	elseif data.hasApply == 0 then
		self.applyBtn:setLangValue(201105);
		self.applyBtn:setBtnEnable(true);
	else
		self.applyBtn:setLangValue(201106);
		self.applyBtn:setBtnEnable(false);
	end

	if limitStr == "" then
		self.limitTxt:setLocation(241, -41);
		self.applyBtn:setLocation(242, 2);
	else
		self.limitTxt:setLocation(241, -18);
		self.applyBtn:setLocation(242, 25);
	end
end

function Lua_AllianceListItem:OnApplyBtnClick(go)
	if self.data == nil then return end;
	if DataCenter.roleData.force < self.data.forceCond then
		OperateAlert.showLangValue(201137);
		return;
	end
	if DataCenter.roleData.level < self.data.levelCond then
		OperateAlert.showLangValue(201138);
		return;
	end

	local sec = DataCenter.roleData.serverTime - DataCenter.allianceData.lastQuitTick;
	local limit = DataCenter.allianceUtil:getConstConfig("quit_league_time_limit", 6);
	sec = limit - sec;
	if sec > 0 then
		local str;
		local hour = Mathf.Modf(sec / 3600);
		if hour < 1 then
			if sec < 60 then
				str = "1"..LanUtil.getValue(45);
			else
				str = Mathf.Modf(sec / 60)..LanUtil.getValue(45);
			end
		else
			str = Lua_TimeTransform.transSeconds23(sec, true, false);
		end
		OperateAlert.show(LanUtil.formateStr(201210, str));
		return;
	end
	Lua_ProxyManager.getProxy("Lua_AllianceProxy"):sJoinAlliance(self.data.id);
end