--公会对抗Panel
Lua_AllianceDuelPanel = class("Lua_AllianceDuelPanel", Lua_DisplayObject);

function Lua_AllianceDuelPanel:ctor(p)
	self:superCall("ctor", p, "AllianceDuelPanel_skin");
end

function Lua_AllianceDuelPanel:buildPanel()
	self:superCall("buildPanel");

	self:addLuaEvent("UPDATE_LEAGUE_DUEL_INFO", self, self.updateData);
end

function Lua_AllianceDuelPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.bg:setEnable(false);

	Lua_ProxyManager.getProxy("Lua_AllianceProxy"):sLeagueCompeteInfo();

	self.usRankItemArr = Array();
	self.otherRankItemArr = Array();

	self.logRedPoint = Lua_RedPointIcon.new(self.content, Lua_RedPointList.LeagueCompeteLog);
	self.logRedPoint:setRectAnchor(1);
	self.logRedPoint:setLocation(335, -160, 0);

	self.tipBtn:addClickFuntion(self, self.onTipsBtnClick);
	self.hurtBtn:addClickFuntion(self, self.onHurtBtnClick);
	self.robBtn:addClickFuntion(self, self.onRobBtnClick);
	self.teamBtn:addClickFuntion(self, self.onTeamBtnClick);
	self.duelBtn:addClickFuntion(self, self.onDuelBtnClick);
end

function Lua_AllianceDuelPanel:dispose()
	if self.usRankItemArr ~= nil then
		self.usRankItemArr:dispose();
		self.usRankItemArr = nil;
	end
	if self.otherRankItemArr ~= nil then
		self.otherRankItemArr:dispose();
		self.otherRankItemArr = nil;
	end

	DataCenter.preLoadData:removeBySign("Lua_HeroLineupWindow", self, self.onTeamSceneShow);
	DataCenter.preLoadData:removeBySign("Lua_FightLineupWindow", self, self.onDuelSceneShow);
	self:superCall("dispose");
end

function Lua_AllianceDuelPanel:updateData()
	local data = DataCenter.allianceData;

	if data.competeFightNum > 0 then
		self.hurtCountTxt.text = LanUtil.formateStr(201259, data.competeFightNum);
	else
		self.hurtCountTxt.text = LanUtil.formateStr(201260, data.competeFightNum);
	end

	if data.isDailyHurt and data.competeGrabNum > 0 then
		self.robCountTxt.text = LanUtil.formateStr(201261, data.competeGrabNum);
		if self.robRedPointIcon == nil then
			self.robRedPointIcon = Lua_RedPointIcon.new(self.content);
			self.robRedPointIcon:setRectAnchor(1);
			self.robRedPointIcon:createRedPointEff();
			self.robRedPointIcon:setLocation(335, -270, 0);
		end
		local serverLimit = DataCenter.redPointData:getRedPointStateById(Lua_RedPointList.LeagueCompeteNum);
		self.robRedPointIcon:updateRedPointShow(tonumber(tostring(data.competeMatchInfo.total_hurt)) > 0 and serverLimit);
	else
		self.robCountTxt.text = LanUtil.formateStr(201262, data.competeGrabNum);
		if self.robRedPointIcon ~= nil then
			self.robRedPointIcon:updateRedPointShow(false);
		end
	end

	local isOpen = data.competeStage == 1;
	if isOpen then
		self.titleTxt:setLangValue(201263);

		if data.competeJoinType == 2 then
			self.tipTxt:setLangValue(201264);
		elseif data.competeJoinType == 3 then
			self.tipTxt:setLangValue(201265);
		elseif data.competeJoinType == 4 then
			self.tipTxt:setLangValue(201298);
		end
		if data.competeJoinType == 1 then
			self.duelBtn:setStyle(20);
		else
			self.duelBtn:setStyle(22);
		end
		self.duelBtn:setMouseEnable(data.competeJoinType == 1);
	else
		self.titleTxt:setLangValue(201266);
		self.duelBtn:setStyle(22);
		self.duelBtn:setMouseEnable(false);
	end

	self.remainTimeTxt:setEnable(isOpen);
	self.openTimeTxt:setEnable(not isOpen);
	self.tipImg:setEnable(isOpen and data.competeJoinType ~= 1);
	self.tipTxt:setEnable(isOpen and data.competeJoinType ~= 1);

	self.time = DataCenter.allianceData.competeEndTick - DataCenter.roleData.serverTime + 1;
	self.timeType = data.competeStage;
	self:onTimer();
	self:startTimer();

	self:updateRankShow();
end

function Lua_AllianceDuelPanel:updateRankShow()
	local data = DataCenter.allianceData;
	local allianceUtil = DataCenter.allianceUtil;

	local rankInfo = data.competeMyRank;
	if rankInfo.rank == 0 then
		self.myRankTxt:setLangValue(201267);
		self.myNameTxt.text = LanUtil.formateStr(201268, DataCenter.roleData.name);
		self.myHurtTxt.text = "";
	else
		self.myRankTxt.text = LanUtil.formateStr(201269, rankInfo.rank);
		self.myNameTxt.text = rankInfo.name;
		self.myHurtTxt.text = LanUtil.formateStr(201270, allianceUtil:transNumber(rankInfo.total_hurt, false), allianceUtil:transNumber(rankInfo.daily_hurt));
	end

	local rankItem;
	rankInfo = data.competeUsInfo;
	for i = 1, 5 do
		rankItem = self.usRankItemArr[i];
		if rankItem == nil then
			rankItem = Lua_AllianceDuelHurtItem.new(self.content, 1, i);
			rankItem:setRectAnchor(7);
			rankItem:setLocation(-230, 425 - (i - 1) * 57, 0);
			self.usRankItemArr:add(rankItem);
		end
		rankItem:setData(rankInfo.role_list[i]);
	end
	if rankInfo.league_id == 0 then
		local leagueInfo = data.myLeagueInfo;
		self.leagueServerTxt.text = leagueInfo.serverPrev;
		self.leagueNameTxt.text = leagueInfo.name;
		self.leagueHurtTxt.text = "0";
	else
		self.leagueServerTxt.text = rankInfo.server_prev;
		self.leagueNameTxt.text = rankInfo.league_name;
		self.leagueHurtTxt.text = LanUtil.formateStr(201270, allianceUtil:transNumber(rankInfo.total_hurt, false), allianceUtil:transNumber(rankInfo.daily_hurt));
	end
	self.leagueNameTxt:resetSize();
	self.leagueHurtTxt:setLocation(-335 + self.leagueNameTxt.preferredWidth, 469, 0);
	
	rankInfo = data.competeMatchInfo;
	for i = 1, 5 do
		rankItem = self.otherRankItemArr[i];
		if rankItem == nil then
			rankItem = Lua_AllianceDuelHurtItem.new(self.content, 2, i);
			rankItem:setRectAnchor(7);
			rankItem:setLocation(165, 425 - (i - 1) * 57, 0);
			self.otherRankItemArr:add(rankItem);
		end
		rankItem:setData(rankInfo.role_list[i]);
	end
	if rankInfo.league_id == 0 then
		self.otherServerTxt.text = "";
		self.otherNameTxt:setLangValue(201271);
		self.otherHurtTxt.text = "";
	else
		self.otherServerTxt.text = rankInfo.server_prev;
		self.otherNameTxt.text = rankInfo.league_name;
		self.otherHurtTxt.text = LanUtil.formateStr(201270, allianceUtil:transNumber(rankInfo.total_hurt, false), allianceUtil:transNumber(rankInfo.daily_hurt));
	end
	self.otherNameTxt:resetSize();
	self.otherHurtTxt:setLocation(60 + self.otherNameTxt.preferredWidth, 469, 0);
end

function Lua_AllianceDuelPanel:startTimer()
	if not self.isTimer then
		self.isTimer = true;
		self:addTimer("onTimer", 1, self, self.onTimer);
	end
end

function Lua_AllianceDuelPanel:onTimer()
	self.time = self.time - 1;
	if self.time < 0 then
		self.time = 0;
		Lua_ProxyManager.getProxy("Lua_AllianceProxy"):sLeagueCompeteInfo();
	end

	if self.timeType == 1 then
		self.remainTimeTxt.text = Lua_TimeTransform.transSeconds26(self.time, true, true);
	else
		self.openTimeTxt.text = LanUtil.formateStr(201272, Lua_TimeTransform.transSeconds20(self.time, true, true));
	end
end

function Lua_AllianceDuelPanel:onTipsBtnClick()
	Lua_WindowUtil.openWin("Lua_AllianceDuelRuleWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_AllianceDuelPanel:onHurtBtnClick()
	Lua_WindowUtil.openWin("Lua_AllianceDuelLogWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_AllianceDuelPanel:onRobBtnClick()
	if DataCenter.allianceData.competeStage == 2 then
		OperateAlert.showLangValue(201273);
		return;
	end
	Lua_WindowUtil.openWin("Lua_AllianceDuelRobWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_AllianceDuelPanel:onTeamBtnClick()
	local param = { Lua_HeroUtil.LINEUP_LRAGUEDUEL_ATTACK, Lua_HeroUtil.LINEUP_LRAGUEDUEL_DEFENSIZE };
	local sceneId = DataCenter.heroLineupData:getLineUpSceneId(Lua_HeroUtil.LINEUP_LRAGUEDUEL_ATTACK);
	DataCenter.preLoadData:preShowScene("Lua_HeroLineupWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onTeamSceneShow, param, sceneId, 0);
end

function Lua_AllianceDuelPanel:onTeamSceneShow(param)
	Lua_WindowUtil.openWin("Lua_HeroLineupWindow", Lua_WinParam.ACTION_OPEN, param);
end

function Lua_AllianceDuelPanel:onDuelBtnClick()
	if DataCenter.allianceData.competeFightNum <= 0 then
		OperateAlert.showLangValue(201274);
		return;
	end

	local sceneId = DataCenter.heroLineupData:getFightLineupSceneId(Lua_FightDefine.TEMPLATE_ID_LEAGUEDUELBOSS);
	DataCenter.preLoadData:preShowScene("Lua_FightLineupWindow", Lua_PreLoadDefine.LOADSHOW_TYPE_NONE, self, self.onDuelSceneShow, nil, sceneId, 0);
end

function Lua_AllianceDuelPanel:onDuelSceneShow(param)
	local list = { template_id = Lua_FightDefine.TEMPLATE_ID_LEAGUEDUELBOSS, monster_player_id = DataCenter.allianceData.competeBossId };
	Lua_WindowUtil.openWin("Lua_FightLineupWindow", Lua_WinParam.ACTION_OPEN, list);
end


























Lua_AllianceDuelHurtItem = class("Lua_AllianceDuelHurtItem", Lua_DisplayObject);

function Lua_AllianceDuelHurtItem:ctor(p, _type, idx)
	self._type = _type;
	self.idx = idx;
	self:superCall("ctor", p, "AllianceDuelHurtItem_skin");
end

function Lua_AllianceDuelHurtItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_AllianceDuelHurtItem:dispose()
	self:superCall("dispose");
end

function Lua_AllianceDuelHurtItem:setData(data)
	if data == nil then
		self.nameTxt:setLangValue(201275);
		self.hurtTxt.text = "";
	else
		self.nameTxt.text = data.name;

		local allianceUtil = DataCenter.allianceUtil;
		if self._type == 1 then
			self.hurtTxt.text = LanUtil.formateStr(201276, allianceUtil:transNumber(data.total_hurt, false), allianceUtil:transNumber(data.daily_hurt));
		else
			self.hurtTxt.text = LanUtil.formateStr(201277, allianceUtil:transNumber(data.total_hurt, false), allianceUtil:transNumber(data.daily_hurt));
		end
	end
	self.rankSp:setAltas("alliance_atlas_1", "xui_ghdk_title_" .. (3 + self.idx));
end